@@ -1,5 +1,5 @@
 import passpy
-from . import StoreInterface, cached
+from . import StoreInterface, cached, ask_secret
 
 
 class Store(StoreInterface):
@@ -19,3 +19,7 @@ class Store(StoreInterface):
             return res
         else:
             raise Exception(f"Secret '{secret}' not found in store '{self.name}'")
+
+    def fill_secret(self, secret):
+        value = ask_secret(self.name, secret)
+        self.store.set_key(secret, value, force=True)
